# **KLASSEZ**

The **KLASSEZ** package is a collection of classes and functions to handle NMR data.

It is organized in modules, each of which contains functions dedicated to specific tasks.

Some of the functions employed by **KLASSEZ** are taken from the NMRGLUE package and modified to suit the needs of the **KLASSEZ** package itself.

---

**KLASSEZ** is developed and tested on *Ubuntu 22.04 LTS*. Other OS should encounter no issues; however, if it raises any errors, please notify.

Full documentation is available at https://klassez.readthedocs.io/latest/.
